clear all
set mem 10000m
set more off
capture log close

/*--------------------------
This file runs regressions and produces summary
statistics using 2004 census data constructued in chiefs_clean_census.do

Last Edit: TR, 5/5/13
---------------------------*/

log using $SL_log/chiefs_analysis_census04_rr.log, replace

/*-------------------
Merging in chiefs data on birth
----------------------*/

use $SL_data/chiefs_survey_clean_out.dta, clear
keep chiefcode mitchell_km coast_dist rail_dist dist_min mining_1930
rename chiefcode chiefcode_birth
sort chiefcode_birth

tempfile corrs
save `corrs'


loc straps = 1000

use $SL_data/chiefs_census_2004.dta, clear
sort chiefcode_birth
merge m:1 chiefcode_birth using `corrs'

/*------------------
1. Regressions
------------------*/

gen private_sector_work_dup = private_sector_work
gen nonag_dup = nonag
  
loc kitchen_sink female age age2 ethnicity*
loc study_controls n_chiefs_`group' amalgamation_`group'

lab var n_chiefs_birth "Chiefs Observed"
lab var n_chiefs_today "Chiefs Observed"
lab var amalgamation_birth "Amalgamation"
lab var amalgamation_today "Amalgamation"
lab var fam_num_ln_birth "Ln(Families)"
lab var fam_num_ln_today "Ln(Families)"

lab var primary "Primary"
lab var nonag "Non-agricultural employment"
lab var literate "Literacy"
lab var secondary "Secondary"

foreach outcome in literate {

if "`outcome'" == "primary"{
  loc group birth
  loc cond 12
}
else if "`outcome'" == "literate"{
  loc group birth
  loc cond 12
}

else if "`outcome'" == "secondary"{
  loc group birth
  loc cond 18
}

else if "`outcome'" =="private_sector_work"{
  loc group today
  loc cond 10
}

else if "`outcome'" =="private_sector_work_dup"{
  loc group birth
  loc cond 10
}

else if "`outcome'" =="nonag"{
  loc group today
  loc cond 10
}

else if "`outcome'" =="nonag_dup"{
  loc group birth
  loc cond 10
}

  loc district_fe dist_`group'*

  loc table_name: variable label `outcome'

if "`group'"=="today" {
  loc group_des "for individuals living in chiefdom today"
}
else {
  loc group_des "for individuals born in chiefdom"
}

sum `outcome' if missing(fam_num_ln_`group')==0 & age>`cond'


/*-------------------------------------------------
Predicted Outcomes with Bootstrapped Standard Errors
---------------------------------------------------*/
/*Core Parameters*/
loc straps = 1000
loc dec = 3
set seed 1000
loc counter=0

/*Bootstrapping Standard Errors*/
matrix coeffs = J(`straps',3,.)
matrix coeffs_d = J(`straps',3,.)
foreach k of numlist 1/`straps'{

  preserve
  bsample, cluster(chiefcode_`group')

  /*Predicting on Bootstrapped Sample*/
  reg `outcome' mitchell_km coast_dist rail_dist dist_min `district_fe' if  age>`cond'
  
  predict `outcome'_p`k' if e(sample), xb
  keep if `outcome'_p`k' !=.
  egen tag = tag(chiefcode_`group')
  keep if tag==1

  /*reg `outcome'_p`k' fam_num_ln_`group' n_chiefs_`group' amalgamation_`group' 

     capture matrix coeffs[`k',1] = _b[fam_num_ln_`group']
     capture matrix coeffs[`k',2] = _b[n_chiefs_`group']
     capture matrix coeffs[`k',3] = _b[amalgamation_`group']*/
  
  reg `outcome'_p`k' fam_num_ln_`group' n_chiefs_`group' amalgamation_`group'  `district_fe' 

     capture matrix coeffs_d[`k',1] = _b[fam_num_ln_`group']
     capture matrix coeffs_d[`k',2] = _b[n_chiefs_`group']
     capture matrix coeffs_d[`k',3] = _b[amalgamation_`group']

  restore
  }

/*Outputting Standard Errors*/
preserve
clear
svmat coeffs
foreach i of numlist 1/3{
  sum coeffs`i', d
  loc se`i' = round( r(sd),0.001)
}

save $SL_out/chiefs_bias_bstrap_`outcome', replace

clear
svmat coeffs_d
foreach i of numlist 1/3{
  sum coeffs_d`i', d
  loc se_d`i' = round( r(sd),0.001)
}

save $SL_out/chiefs_bias_bstrap_d_`outcome', replace
restore

/*2. Creating Predicted Values Using Original Sample*/
reg `outcome' mitchell_km coast_dist rail_dist dist_min mining_1930 `district_fe' if  age>`cond'
predict `outcome'_p if e(sample), xb

/*3. Regressing Original Predictions on Number of Families and Outputting with S.E.*/
preserve
keep if `outcome'_p !=.
egen tag = tag(chiefcode_`group')
keep if tag==1

/*Summarizing*/
sum `outcome'_p
loc mean = round(r(mean),0.001)
loc sd = round(r(sd),0.001)

if `counter' == 0{
  loc rcond replace
}
else{
  loc rcond
}

loc counter = `counter' + 1

/*Reporting Regressions*/

/*reg `outcome'_p fam_num_ln_`group' n_chiefs_`group'  amalgamation_`group'  ,  r

outreg2 using "$SL_out/chiefs_table_cen_indiv_bias_test.tex", `rcond' tex keep (fam_num_ln_`group' n_chiefs_`group'  amalgamation_`group') dec(3) nocons  ctitle("`outcome'")   addtext(District FE , NO,  Family se, `se1' , N_chiefs se, `se2', Amalgamation se, `se3' , Outcome mean, `mean', Outcome s.d., `sd' )  addnote("Bootstrapped standard errors use 500 iterations") label*/

reg `outcome'_p fam_num_ln_`group' n_chiefs_`group'  amalgamation_`group'  `district_fe' ,  r 

outreg2 using "$SL_out/chiefs_table_cen_indiv_bias_test.tex", `rcond' tex keep (fam_num_ln_`group' n_chiefs_`group'  amalgamation_`group') dec(3) nocons  ctitle("`outcome'")  addtext(District FE ,YES,  Family se, `se_d1' , N_chiefs se , `se_d2', Amalgamation se, `se_d3',  Outcome mean, `mean', Outcome s.d., `sd' ) addnote("Bootstrapped standard errors use 500 iterations") label
restore
}








log close
