set more off
set matsize 11000

/*---------------------------------------
This file does permutation based
inference on a select number of variables
--------------------------------------*/

/*----------------------------
0. Preliminaries
----------------------------*/

set seed 1000
loc straps = 1000

/*-----------------------------
1. Creating Placebo Effects
------------------------------*/
loc run = 0
if `run' == 1{

/*1. Getting Original Number of Families*/
use $SL_data/chiefs_survey_clean_out.dta, clear

keep chiefcode fam_num_ln
rename fam_num_ln fam_num_ln_0
gen id = _n

sort id
tempfile chiefs
save `chiefs'

keep fam_num_ln_0

/*2. Sampling Empirical Distribution of Number of Families*/
foreach k of numlist 1/`straps'{
  preserve
  bsample
  rename fam_num_ln_0 fam_num_ln_`k'
  gen id = _n
  sort id

  qui merge 1:1 id using `chiefs'
  drop _m
  qui save `chiefs', replace
  restore
}
  
use `chiefs', clear
sort chiefcode
save $SL_data/chiefs_analysis_placebo.dta, replace
}


/*-----------------------------------------------------------
2. Getting Distribution of Treatment Effects under Placebos
---------------------------------------------------------------*/
loc run = 1
if `run' == 1{

capture log close
log using $SL_log/chiefs_analysis_placebo.do, replace
  
use $SL_data/chiefs_nps_birth_rr.dta, replace

loc outcomes commmeet lcmeet chiefmeet school_group labor_gang secret_society roadbrush 
loc devoutcomes primary nicefloor phone member role_pc role_headman
loc controls female age age2 ethnicity*
loc study_controls n_chiefs amalgamation
loc district_fe dist? dist??
loc elite role_pc member role_headman

/*Bringing in Placebos*/
merge m:1 chiefcode using $SL_data/chiefs_analysis_placebo.dta
drop _m

compare fam_num_ln fam_num_ln_0

lab var respect_authority "Believes we should respect authority more"
lab var commmeet "Has attended community meeting"
lab var chiefmeet "Has been to meeting with chief"
lab var secret_society "Is member of secret society"
lab var roadbrush "Has participated in road brushing"
lab var phone "Owns mobile phone"
lab var nicefloor "Has cement or tile floor"
lab var primary "Primary education attainment"
lab var school_group "Member of school group"

lab var bridging "Bridging capital index"
lab var bonding "Bonding capital index"
lab var collective "Collective action index"

/*Looping over Outcomes of Interest*/
foreach y of varlist  bridging bonding collective /*school_grouprespect_authority commmeet chiefmeet secret_society roadbrush phone nicefloor primary*/ {

local title: variable label `y'
  
/*Original Regression*/
reg `y' fam_num_ln `study_controls' `district_fe' `controls'  [pw = inv_prob] 

loc b0_`y' = round(_b[fam_num_ln],0.001)

/*Preparing Empty Matrix to Store Coefficients from Placebo Model*/
matrix b`y' = J(`straps',1,.)

/*Running Placebo Regressions*/
foreach k of numlist 1/`straps' {
    qui reg `y' fam_num_ln_`k' `study_controls' `district_fe' `controls'  [pw = inv_prob] 
    matrix b`y'[`k',1] = _b[fam_num_ln_`k']
}

/*Outputting Placebo Coefficients*/
preserve

clear
svmat b`y', names(col)
rename c1 b`y'_placebo
gen b`y'_true = `b0_`y''

/*1. Summarizing*/
di "Distribution of placebo effects on `y'"
sum b`y'_placebo, d
di "True effect: `b0_`y''"

/*2. Getting Number of times effect is less than placebo*/
gen lessthan = (b`y'_true > b`y'_placebo)
label var lessthan "Percent of times placebo is less than treatment"
sum lessthan
loc lessthan_pc = 100*round(r(mean),0.001)

gen greaterthan = (b`y'_true < b`y'_placebo)
label var greaterthan "Percent of times placebo is greater than treatment"
sum greaterthan
loc greaterthan_pc = 100*round(r(mean),0.001)

/*3. Density Plot*/
loc bins = `straps'/20
  
histogram b`y'_placebo, xline(`b0_`y'', lpattern(dash) ) percent xtitle("Placebo effects of log number of ruling families") note( "Dashed line indicates true estimate of `b0_`y'' in NPS sample; `lessthan_pc'% of placebo effects are less." "Placebos generated `straps' times." ) title("`title'") bin(`bins') scheme(sj)

graph save $SL_graph/placebo_less_`y', replace

histogram b`y'_placebo, xline(`b0_`y'', lpattern(dash) ) percent xtitle("Placebo effects of log number of ruling families") note( "Dashed line indicates true estimate of `b0_`y'' in NPS sample; `greaterthan_pc'% of placebo effects are greater." "Placebos generated `straps' times.") title("`title'") bin(`bins') scheme(sj)

graph save $SL_graph/placebo_greater_`y', replace

/*4. Saving Out*/
save $SL_out/placebo_`y'.dta, replace

restore

}

log close

/*End Run Loop*/
}


