clear all
set mem 10000m
set more off
capture log close

/*--------------------------
This file produces Table 4 using data from the NPS and the Census.
Census files were constructed by chiefs_clean_census_rr.do, NPS files constructed
by chiefs_clean_nps_birth_rr.do.

Census data is confidential and mantained by Statistics Sierra Leone. It cannot be shared.

Last Edit: TR, 5/29/13
---------------------------*/

log using $SL_log/chiefs_table4_rr2.log, replace

/*--------------------
PART 0: Preliminaries
----------------------*/
loc exocontrol mitchell_km coast_dist rail_dist river_dist dist_min mining_1930
loc kitchen_sink female age age2 ethnicity*

/*---------------------
PART I: Regressions
----------------------*/
  
/*-------------------------------
1. Beginning with Census Data
-----------------------------------*/
use $SL_data/chiefs_census_2004_birth.dta, clear

lab var fam_num_ln "Ln(Families)"
lab var fam_num "Families"
lab var amalgamation "Amalgamation"
lab var n_chiefs "Number of chiefs recalled"

foreach outcome in literate primary secondary {
if "`outcome'" == "primary"{
  loc cond 12
}
else if "`outcome'" == "literate"{
  loc cond 12
}

else if "`outcome'" == "secondary"{
  loc cond 18
}

  loc district_fe dist*
  loc table_name: variable label `outcome'

/*Mean*/
sum `outcome' if missing(fam_num_ln)==0 & age>`cond'

/*-------------------------------------------
1.A. Study Controls, District fixed effects
--------------------------------------------*/

/*Getting Condition for Outreg*/
if "`outcome'" == "literate"{
   loc rcond replace
}
else {
    loc rcond
  }

/*Without historical Controls*/
  reg `outcome' fam_num_ln n_chiefs amalgamation dist?? dist? if  age>`cond' ,  r  cluster(chiefcode_birth)

outreg2 using "$SL_out/chiefs_table4", `rcond' tex(frag) keep (fam_num_ln  n_chiefs amalgamation) dec(3) nocons    ctitle("`outcome'") label nonotes addtext( District fixed effects, YES, Demographic Controls, NO, Historical controls, NO)  sortvar(fam_num_ln   amalgamation n_chiefs) noaster

/*With historical Controls*/
  reg `outcome' fam_num_ln n_chiefs amalgamation dist?? dist?  `exocontrol'  if  age>`cond' ,  r  cluster(chiefcode_birth)

outreg2 using "$SL_out/chiefs_table4_exocontrol", `rcond' tex(frag) keep (fam_num_ln  n_chiefs amalgamation) dec(3) nocons    ctitle("`outcome'") label nonotes addtext( District fixed effects, YES, Demographic Controls, NO, Historical controls, YES)  sortvar(fam_num_ln   amalgamation n_chiefs) noaster

/*-----------------------------------------------------------------
1.B. Study Controls, District fixed effects,  Demographic Controls
------------------------------------------------------------------*/

/*Without Historical Controls*/  
  reg `outcome' fam_num_ln n_chiefs amalgamation  dist?? dist? `kitchen_sink'   if  age>`cond' ,  r  cluster(chiefcode_birth)

outreg2 using "$SL_out/chiefs_table4", tex(frag) keep (fam_num_ln  n_chiefs amalgamation) dec(3) nocons  ctitle("`outcome'") label addtext( District fixed effects, YES, Demographic Controls, YES, Historical controls, NO) sortvar(fam_num_ln   amalgamation n_chiefs) noaster
  
/*With Historical Controls*/  
  reg `outcome' fam_num_ln n_chiefs amalgamation  dist?? dist? `kitchen_sink'  `exocontrol'  if  age>`cond' ,  r  cluster(chiefcode_birth)

outreg2 using "$SL_out/chiefs_table4_exocontrol", tex(frag) keep (fam_num_ln  n_chiefs amalgamation) dec(3) nocons  ctitle("`outcome'") label addtext( District fixed effects, YES, Demographic Controls, YES, Historical controls, YES) sortvar(fam_num_ln   amalgamation n_chiefs) noaster

/*---------------------------------------------------------------------
1.C. Functional form testing, for literacy
----------------------------------------------------------------------*/
if "`outcome'" == "literate"{

/*Without Historical Controls*/  
  reg `outcome' fam_num_ln fam_num n_chiefs amalgamation  dist?? dist? `kitchen_sink'   if  age>`cond' ,  r  cluster(chiefcode_birth)

outreg2 using "$SL_out/chiefs_table4", tex(frag) keep (fam_num fam_num_ln  n_chiefs amalgamation) dec(3) nocons  ctitle("`outcome'") label addtext( District fixed effects, YES, Demographic Controls, YES, Historical controls, NO) sortvar(fam_num_ln fam_num amalgamation n_chiefs) noaster
  
/*With Historical Controls*/  
  reg `outcome' fam_num_ln fam_num n_chiefs amalgamation  dist?? dist? `kitchen_sink'  `exocontrol'  if  age>`cond' ,  r  cluster(chiefcode_birth)

outreg2 using "$SL_out/chiefs_table4_exocontrol", tex(frag) keep (fam_num fam_num_ln  n_chiefs amalgamation) dec(3) nocons  ctitle("`outcome'") label addtext( District fixed effects, YES, Demographic Controls, YES, Historical controls, YES) sortvar(fam_num_ln fam_num amalgamation n_chiefs) noaster
  
}

/*-----------------------------------------------------------------
2. For primary and secondary education, doing same variable in NPS
--------------------------------------------------------------*/
if "`outcome'"=="primary" | "`outcome'" == "secondary" {

preserve

use $SL_data/chiefs_nps_birth_rr.dta, replace

lab var fam_num_ln "Ln(Families)"
lab var amalgamation "Amalgamation"
lab var n_chiefs "Number of chiefs recalled"

  /*Generating Summary Statistics for Table 1*/
  mean `outcome' if missing(fam_cat) ==0

  matrix define M = e(b)
  loc mean = round(M[1,1],0.001)

  tabstat `outcome' [fw = round(inv_prob) ], by(fam_cat) stat(mean sd)
  
/*-----------------------------------------------------------------
2.A. Regression with District fixed effects and Controls
------------------------------------------------------------------*/

  /*Without Historical Controls*/
  reg `outcome' fam_num_ln  n_chiefs amalgamation dist? dist??  `kitchen_sink'  [pw = inv_prob] , r cluster(chiefcode)

  outreg2 using "$SL_out/chiefs_table4.tex", `rcond'  tex(frag) keep (fam_num_ln  n_chiefs amalgamation)  dec(3)  ctitle("`outcome'") nonotes noaster nocons label addtext( District fixed effects, YES, Demographic Controls, YES, Historical controls, NO) sortvar(fam_num_ln   amalgamation n_chiefs)

  /*With Historical Controls*/
  reg `outcome' fam_num_ln  n_chiefs amalgamation dist? dist??  `kitchen_sink'  `exocontrol' [pw = inv_prob] , r cluster(chiefcode)

  outreg2 using "$SL_out/chiefs_table4_exocontrol.tex", `rcond'  tex(frag) keep (fam_num_ln  n_chiefs amalgamation)  dec(3)  ctitle("`outcome'") nonotes noaster nocons label addtext( District fixed effects, YES, Demographic Controls, YES, Historical controls, YES) sortvar(fam_num_ln   amalgamation n_chiefs)

restore
}
  
/*-----------------------------------------------------------------------------------------
4. Study Controls, District fixed effects, Demographic Controls, Researcher fixed effects, No Historical Controls (just census)
-------------------------------------------------------------------------------------------*/
  
reg `outcome' fam_num_ln n_chiefs amalgamation research_dummy* `district_fe' `kitchen_sink'   if  age>`cond' ,  r  cluster(chiefcode_birth)

outreg2 using "$SL_out/chiefs_table4_researcher_appendix", `rcond' tex(frag) keep (fam_num_ln) dec(3) nocons  ctitle("`outcome'") addtext( District fixed effects, YES,  Demographic Controls, YES, Researcher fixed effects, YES)  sortvar(fam_num_ln   amalgamation n_chiefs)

}




/*---------------------------
2. Summary Stats
----------------------------*/

loc run = 1
if `run' == 1{

use $SL_data/chiefs_census_2004_birth.dta, clear

replace primary = . if age<12
replace literate = . if age<12
replace secondary = . if age<18
replace nonag = . if age<10

foreach y in literate primary secondary nonag {
  sum `y' if missing(fam_cat)==0
  tabstat `y', by(fam_cat) stat(mean sd)
}


use $SL_data/chiefs_census_2004_today.dta, clear

replace primary = . if age<12
replace literate = . if age<12
replace secondary = . if age<18
replace nonag = . if age<10

foreach y in nonag age female temne mende limba {
  sum `y'  if missing(fam_cat) ==0
  tabstat `y', by(fam_cat) stat(mean sd)
}

}

  
log close
